import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;

class TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const TranslationsDelegate();

  List<Locale> get supportedLocales {
    //MUST update Info tab on iOS Runner project according to this
    return const <Locale>[
      const Locale('en'),
      const Locale('es'),
      const Locale('pt'),
    ];
  }

  @override
  bool isSupported(Locale locale) {
    if (locale != null) {
      for (var supportedLocale in supportedLocales) {
        if (supportedLocale.languageCode == locale.languageCode) {
          return true;
        }
      }
    }
    return false;
  }

  @override
  Future<Translations> load(Locale locale) => Translations.load(locale);

  @override
  bool shouldReload(TranslationsDelegate old) => false;
}

class Translations {
  Translations(Locale locale) {
    this.locale = locale;
    _localizedValues = null;
  }

  static const TranslationsDelegate delegate = TranslationsDelegate();

  Locale locale;
  static Map<dynamic, dynamic> _localizedValues;

  static Translations of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations);
  }

  String text(String key) {
    return _localizedValues[key] ?? '** $key not found';
  }

  static Future<Translations> load(Locale locale) async {
    Translations translations = new Translations(locale);
    try {
      String jsonContent = await rootBundle
          .loadString("lib/assets/i18n/${locale.languageCode}.json");
      _localizedValues = json.decode(jsonContent);
    } catch (ex) {
      print(ex);
      String jsonContent =
          await rootBundle.loadString("lib/assets/i18n/en.json");
      _localizedValues = json.decode(jsonContent);
    }
    return translations;
  }

  get currentLanguage => locale.languageCode;
}
