import 'dart:convert';

import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:crypto/crypto.dart';
import 'package:intl/intl.dart';

abstract class AuthorizationHelper {
  static String getAuthSignature(String currentDateFormatted) {
    final secretKey = utf8.encode(ConfigReader.clientSecretKey!);
    final bytes =
        utf8.encode(ConfigReader.clientApiToken! + ":" + currentDateFormatted);
    final hmacSha256 = Hmac(sha256, secretKey); // HMAC-SHA256
    final digest = hmacSha256.convert(bytes);

    return digest.toString();
  }

  static String getCurrentDateFormatted() {
    final int offset = ConfigReader.dateOffset;
    final currentDate = DateTime.now().add(Duration(milliseconds: offset));

    var dateFormat = DateFormat("yyyy-MM-ddTHH:mm:ss");

    var currentDateFormatted = dateFormat.format(currentDate) +
        (currentDate.timeZoneOffset.isNegative ? "-" : "+") +
        (currentDate.timeZoneOffset.abs().inHours.toString().length > 1
            ? ((currentDate.timeZoneOffset.abs().inMinutes / 60) % 12)
                .toInt()
                .toString()
            : "0" +
                ((currentDate.timeZoneOffset.abs().inMinutes / 60) % 12)
                    .toInt()
                    .toString()) +
        ((currentDate.timeZoneOffset.abs().inMinutes % 60).toString().length > 1
            ? ":" + (currentDate.timeZoneOffset.abs().inMinutes % 60).toString()
            : ":0" +
                (currentDate.timeZoneOffset.abs().inMinutes % 60).toString());
    return currentDateFormatted;
  }
}
