import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v3";

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'local': 'http://localhost:3000/',
  'test': 'https://testapi.dcoupon.com/coupons/',
  'dev': 'https://services-dev.dcoupon.com/coupons/',
  'dcoupon.eu': 'https://services.dcoupon.eu/coupons/',
  'dcoupon.com': 'https://services.dcoupon.com/coupons/'
};

class CouponsApiHelper {
  static Map<String, dynamic> buildHeaders({
    bool userAuthentication = true,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();
    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);

    if (userAuthentication) {
      headers[Constants.HEADER_USER_JWT] = ConfigReader.userJwt;
    }

    return headers;
  }

  static String getRedemptionTokenUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/redemptionToken';
  }

  static String getCouponsListUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! + VERSION + '/list';
  }

  static String getCreateUserCouponsUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/createUserCoupon/';
  }

  static String getCouponDetailUrl(String couponId) {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/detail/' +
        couponId;
  }

  static String getActivateCouponUrl(String couponId) {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/activate/' +
        couponId;
  }

  static String getDeactivateCouponUrl(String couponId) {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/deactivate/' +
        couponId;
  }

  static String getUserCouponsRetailers() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/retailers';
  }

  static String getUserCouponsCompanies() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/companies';
  }
}
