import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v3";

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'local': 'http://10.0.2.2:3000/publisher/',
  'test': 'https://testapi.dcoupon.com/publisher/',
  'dev': 'https://services-dev.dcoupon.com/publisher/',
  'dcoupon.eu': 'https://services.dcoupon.eu/publisher/',
  'dcoupon.com': 'https://services.dcoupon.com/publisher/'
};

class PublisherApiHelper {
  static Map<String, dynamic> buildHeaders() {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();

    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);

    return headers;
  }

  static String getStoresUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/stores/';
  }

  static String getPromotionsUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/promotions/';
  }

  static String getPromotionDetailUrl(String promotionToken) {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/promotion/' +
        promotionToken;
  }

  static String getRetailersUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/retailers/';
  }

  static String getCategoriesUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/categories/';
  }

  static String getCompaniesUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        '/companies/';
  }
}
