import 'package:dcoupon_sdk_flutter_package/src/data/models/enrollment_form_model.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';
import 'package:dio/dio.dart';

class UserLoginResponse {
  final String? sessionToken;

  UserLoginResponse({
    this.sessionToken,
  });

}

class UserLoginSuccessResponse extends UserLoginResponse {
  final ClientType? clientType;

  UserLoginSuccessResponse({
    required String? sessionToken,
    required this.clientType,
  }) : super(
          sessionToken: sessionToken,
        );

  factory UserLoginSuccessResponse.fromResponse(Response<dynamic> response) {
    final Map<String, dynamic> json = response.data;
    final headersMap = response.headers.map;
    final String clientTypeString =
        headersMap[Constants.HEADER_CLIENT_TYPE]!.first;
    return UserLoginSuccessResponse(
      sessionToken: json[Constants.SESSION_TOKEN],
      clientType:
          EnumHelper.enumFromString(clientTypeString, ClientType.values),
    );
  }
}

class UserLoginEnrollmentNeededResponse extends UserLoginResponse {
  final EnrollmentForm? enrollmentForm;

  UserLoginEnrollmentNeededResponse({
    required String? sessionToken,
    required this.enrollmentForm,
  }) : super(
          sessionToken: sessionToken,
        );

  factory UserLoginEnrollmentNeededResponse.fromResponse(Response<dynamic> response) {
    final Map<String, dynamic> json = response.data;

    return UserLoginEnrollmentNeededResponse(
      sessionToken: json[Constants.SESSION_TOKEN],
      enrollmentForm: EnrollmentFormModel.fromJson(json[Constants.FORM]),
    );
  }
}