import 'dart:async';

import 'package:dartz/dartz.dart';

import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/loyalty_remote_data_source.dart';

import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/loyalty_repository.dart';



class LoyaltyRepositoryImpl implements LoyaltyRepository {
  final LoyaltyRemoteDataSource? remoteDataSource;

  LoyaltyRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, dynamic>> getLoyaltyAffiliates() async {
    return await remoteDataSource!.getLoyaltyAffiliates();
  }

  @override
  Future<Either<Failure, dynamic>> getUserLoyaltyCards() async {
    return await remoteDataSource!.getUserLoyaltyCards();
  }

  @override
  Future<Either<Failure, dynamic>> addOrUpdateLoyaltyCard({
    required String affiliateApiToken,
    required Map<String, dynamic> formData,
  }) async {
    return await remoteDataSource!.addOrUpdateLoyaltyCard(
      affiliateApiToken: affiliateApiToken,
      formData: formData,
    );
  }

  @override
  Future<Either<Failure, dynamic>> deleteLoyaltyCard({
    required String affiliateApiToken,
    required String cardNumber,
  }) async {
    return await remoteDataSource!.deleteLoyaltyCard(
      affiliateApiToken: affiliateApiToken,
      cardNumber: cardNumber,
    );
  }
}
