import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';
import 'package:equatable/equatable.dart';

class CouponGetCoupons implements UseCase<dynamic, CouponGetCouponsParams> {
  final CouponRepository? repository;

  CouponGetCoupons(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(CouponGetCouponsParams params) async {
    return await repository!.getCoupons(
      offset: params.offset,
      limit: params.limit,
      sortBy: params.sortBy,
      companyTokens: params.companyTokens,
      retailerTokens: params.retailerTokens,
    );
  }
}

class CouponGetCouponsParams extends Equatable {
  final int? offset;
  final int? limit;
  final String? sortBy;
  final List<String>? companyTokens;
  final List<String>? retailerTokens;

  CouponGetCouponsParams({
    this.offset,
    this.limit,
    this.sortBy,
    this.companyTokens,
    this.retailerTokens,
  });

  @override
  List<Object?> get props => [
        offset,
        limit,
        sortBy,
        companyTokens,
        retailerTokens,
      ];
}
