import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/loyalty_repository.dart';
import 'package:equatable/equatable.dart';

class LoyaltyAddOrUpdateLoyaltyCard
    implements UseCase<dynamic, LoyaltyAddOrUpdateLoyaltyCardParams> {
  final LoyaltyRepository? repository;

  LoyaltyAddOrUpdateLoyaltyCard(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      LoyaltyAddOrUpdateLoyaltyCardParams params) async {
    return await repository!.addOrUpdateLoyaltyCard(
      affiliateApiToken: params.affiliateApiToken,
      formData: params.formData,
    );
  }
}

class LoyaltyAddOrUpdateLoyaltyCardParams extends Equatable {
  final String affiliateApiToken;
  final Map<String, dynamic> formData;

  LoyaltyAddOrUpdateLoyaltyCardParams({
    required this.affiliateApiToken,
    required this.formData,
  });

  @override
  List<Object?> get props => [
        affiliateApiToken,
        formData,
      ];
}
