import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/loyalty_repository.dart';
import 'package:equatable/equatable.dart';

class LoyaltyDeleteLoyaltyCard
    implements UseCase<dynamic, LoyaltyDeleteLoyaltyCardParams> {
  final LoyaltyRepository? repository;

  LoyaltyDeleteLoyaltyCard(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      LoyaltyDeleteLoyaltyCardParams params) async {
    return await repository!.deleteLoyaltyCard(
      affiliateApiToken: params.affiliateApiToken,
      cardNumber: params.cardNumber,
    );
  }
}

class LoyaltyDeleteLoyaltyCardParams extends Equatable {
  final String affiliateApiToken;
  final String cardNumber;

  LoyaltyDeleteLoyaltyCardParams({
    required this.affiliateApiToken,
    required this.cardNumber,
  });

  @override
  List<Object?> get props => [
        affiliateApiToken,
        cardNumber,
      ];
}
