import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/store_repository.dart';
import 'package:equatable/equatable.dart';

class StoreGetStores implements UseCase<dynamic, StoreGetStoresParams> {
  final StoreRepository? repository;

  StoreGetStores(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(StoreGetStoresParams params) async {
    return await repository!.getStores(
      promotionToken: params.promotionToken,
      start: params.start,
      limit: params.limit,
      retailerTokens: params.retailerTokens,
      zipcode: params.zipcode,
      latitude: params.latitude,
      longitude: params.longitude,
      radius: params.radius,
      publisherToken: params.publisherToken,
    );
  }
}

class StoreGetStoresParams extends Equatable {
  final String? promotionToken;
  final int? start;
  final int? limit;
  final List<String>? retailerTokens;
  final String? zipcode;
  final String? latitude;
  final String? longitude;
  final String? radius;
  final String? publisherToken;

  StoreGetStoresParams({
    this.promotionToken,
    this.start,
    this.limit,
    this.retailerTokens,
    this.zipcode,
    this.latitude,
    this.longitude,
    this.radius,
    this.publisherToken,
  });

  @override
  List<Object?> get props => [
        promotionToken,
        start,
        limit,
        retailerTokens,
        zipcode,
        latitude,
        longitude,
        radius,
        publisherToken,
      ];
}
