import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_accept_enrollment_form_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';

import 'package:equatable/equatable.dart';

class UserAcceptEnrollmentForm
    implements
        UseCase<UserAcceptEnrollmentFormResponse,
            UserAcceptEnrollmentFormParams> {
  final UserRepository? repository;

  UserAcceptEnrollmentForm(this.repository);

  @override
  Future<Either<Failure, UserAcceptEnrollmentFormResponse>> call(
      UserAcceptEnrollmentFormParams params) async {
    return await repository!.acceptEnrollmentForm(
      jwt: params.jwt,
      legalDocumentsAccepted: params.legalDocumentsAccepted,
    );
  }
}

class UserAcceptEnrollmentFormParams extends Equatable {
  final String? jwt;
  final List<String>? legalDocumentsAccepted;

  UserAcceptEnrollmentFormParams({
    required this.jwt,
    required this.legalDocumentsAccepted,
  });

  @override
  List<Object?> get props => [
        jwt,
        legalDocumentsAccepted,
      ];
}
