import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_login_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';

import 'package:equatable/equatable.dart';

class UserLogIn implements UseCase<UserLoginResponse, UserLogInParams> {
  final UserRepository? repository;

  UserLogIn(this.repository);

  @override
  Future<Either<Failure, UserLoginResponse>> call(
      UserLogInParams params) async {
    return await repository!.login(
      externalId: params.externalId,
      email: params.email,
      referralCode: params.referralCode,
    );
  }
}

class UserLogInParams extends Equatable {
  final String externalId;
  final String? email;
  final String? referralCode;

  UserLogInParams({
    required this.externalId,
    this.email,
    this.referralCode,
  });

  @override
  List<Object?> get props => [
        externalId,
        email,
        referralCode,
      ];
}
