import 'package:dcoupon_sdk_flutter_package/src/data/datasources/coupon_remote_data_sources.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/loyalty_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/promotion_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/redemption_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/store_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/user_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/repositories/coupon_repository_impl.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/repositories/loyalty_repository_impl.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/repositories/promotion_repository_impl.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/repositories/redemption_repository_impl.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/repositories/store_repository_impl.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/repositories/user_repository_impl.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/loyalty_repository.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/redemption_repository.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/store_repository.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_activate_coupon.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_create_user_coupons.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_deactivate_coupon.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_get_coupon_detail.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_get_coupons.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_get_user_coupons_companies.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/coupon_get_user_coupons_retailers.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/loyalty_add_or_update_loyalty_card.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/loyalty_delete_loyalty_card.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/loyalty_get_loyalty_affiliates.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/loyalty_get_user_loyalty_cards.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/promotion_get_categories.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/promotion_get_companies.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/promotion_get_promotion_detail.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/promotion_get_promotions.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/promotion_get_retailers.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/redemption_get_redemption_code.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/redemption_get_redemption_detail.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/redemption_get_user_redemption_history.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/redemption_get_user_redemption_summary.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/store_get_stores.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_accept_enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_get_user_data.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_log_in.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_log_out.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_update_user_data.dart';
import 'package:get_it/get_it.dart';

final sl = GetIt.instance;

Future<void> init() async {
  // Use cases
  sl.registerLazySingleton(() => UserLogIn(sl()));
  sl.registerLazySingleton(() => UserLogOut(sl()));
  sl.registerLazySingleton(() => UserAcceptEnrollmentForm(sl()));
  sl.registerLazySingleton(() => UserGetUserData(sl()));
  sl.registerLazySingleton(() => UserUpdateUserData(sl()));

  sl.registerLazySingleton(() => LoyaltyGetLoyaltyAffiliates(sl()));
  sl.registerLazySingleton(() => LoyaltyGetUserLoyaltyCards(sl()));
  sl.registerLazySingleton(() => LoyaltyAddOrUpdateLoyaltyCard(sl()));
  sl.registerLazySingleton(() => LoyaltyDeleteLoyaltyCard(sl()));

  sl.registerLazySingleton(() => RedemptionGetUserRedemptionSummary(sl()));
  sl.registerLazySingleton(() => RedemptionGetUserRedemptionHistory(sl()));
  sl.registerLazySingleton(() => RedemptionGetRedemptionDetail(sl()));
  sl.registerLazySingleton(() => RedemptionGetRedemptionCode(sl()));

  sl.registerLazySingleton(() => CouponActivateCoupon(sl()));
  sl.registerLazySingleton(() => CouponDeactivateCoupon(sl()));
  sl.registerLazySingleton(() => CouponCreateUserCoupons(sl()));
  sl.registerLazySingleton(() => CouponGetCouponDetail(sl()));
  sl.registerLazySingleton(() => CouponGetCoupons(sl()));
  sl.registerLazySingleton(() => CouponGetUserCouponsCompanies(sl()));
  sl.registerLazySingleton(() => CouponGetUserCouponsRetailers(sl()));

  sl.registerLazySingleton(() => StoreGetStores(sl()));

  sl.registerLazySingleton(() => PromotionGetPromotions(sl()));
  sl.registerLazySingleton(() => PromotionGetPromotionDetail(sl()));
  sl.registerLazySingleton(() => PromotionGetCategories(sl()));
  sl.registerLazySingleton(() => PromotionGetCompanies(sl()));
  sl.registerLazySingleton(() => PromotionGetRetailers(sl()));

  // Repositories
  sl.registerLazySingleton<UserRepository>(
    () => UserRepositoryImpl(
      remoteDataSource: sl(),
    ),
  );

  sl.registerLazySingleton<LoyaltyRepository>(
    () => LoyaltyRepositoryImpl(
      remoteDataSource: sl(),
    ),
  );

  sl.registerLazySingleton<RedemptionRepository>(
    () => RedemptionRepositoryImpl(
      remoteDataSource: sl(),
    ),
  );

  sl.registerLazySingleton<CouponRepository>(
    () => CouponRepositoryImpl(
      remoteDataSource: sl(),
    ),
  );

  sl.registerLazySingleton<StoreRepository>(
    () => StoreRepositoryImpl(
      remoteDataSource: sl(),
    ),
  );

  sl.registerLazySingleton<PromotionRepository>(
    () => PromotionRepositoryImpl(
      remoteDataSource: sl(),
    ),
  );

  // Data sources
  sl.registerLazySingleton<UserRemoteDataSource>(
    () => UserRemoteDataSourceImpl(),
  );

  sl.registerLazySingleton<LoyaltyRemoteDataSource>(
    () => LoyaltyRemoteDataSourceImpl(),
  );

  sl.registerLazySingleton<RedemptionRemoteDataSource>(
    () => RedemptionRemoteDataSourceImpl(),
  );

  sl.registerLazySingleton<CouponRemoteDataSource>(
    () => CouponRemoteDataSourceImpl(),
  );

  sl.registerLazySingleton<StoreRemoteDataSource>(
    () => StoreRemoteDataSourceImpl(),
  );

  sl.registerLazySingleton<PromotionRemoteDataSource>(
    () => PromotionRemoteDataSourceImpl(),
  );
}
