import 'dart:collection';

import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/legal_document.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form/widgets/legal_doc_changes_widget.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/material.dart';

enum LegalDocumentExpansionPanel {
  VERSION_CHANGES,
  MAJOR_CHANGES,
}

class LegalDocListItemWidget extends StatefulWidget {
  final LegalDocument legalDocument;
  final VoidCallback onTap;

  LegalDocListItemWidget({
    Key? key,
    required this.legalDocument,
    required this.onTap,
  }) : super(key: key);

  @override
  State<LegalDocListItemWidget> createState() => _LegalDocListTileWidgetState();
}

class _LegalDocListTileWidgetState extends State<LegalDocListItemWidget> {
  late bool _hasPreviousAgreement;

  @override
  void initState() {
    super.initState();
    _hasPreviousAgreement =
        widget.legalDocument.versionChangesTextMap(ConfigReader.languageCode).isNotEmpty;
  }

  List<Widget> _generateVersionListTiles() {
    final List<Widget> listTiles = [];

    final sortedVersionChangesTextMap = SplayTreeMap<String,dynamic>.from( widget.legalDocument.versionChangesTextMap(ConfigReader.languageCode), (a, b) => b.compareTo(a));

    sortedVersionChangesTextMap.forEach(
      (key, value) {
        listTiles.add(
          LegalDocChangesWidget(
            version: key,
            changes: value,
          ),
        );
      },
    );

    return listTiles;
  }

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: <Widget>[
            Text(
              Translations.of(context)!
                  .text('dcoupon_legal_${widget.legalDocument.type}')
                  .toUpperCase(),
              style: Theme.of(context).textTheme.headline6,
            ),
            SizedBox(height: 16.0),
            GestureDetector(
              onTap: widget.onTap,
              child: Container(
                padding: EdgeInsets.all(4.0),
                decoration: BoxDecoration(
                  border: Border.all(
                    color: DCouponColors.dCouponPrimaryOrange,
                  ),
                  borderRadius: BorderRadius.circular(10.0),
                ),
                width: double.infinity,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Icon(Icons.assignment),
                    SizedBox(width: 8),
                    Text(Translations.of(context)!.text('view_document'))
                  ],
                ),
              ),
            ),
            SizedBox(height: 16.0),
            _hasPreviousAgreement
                ? ExpansionTile(
                    initiallyExpanded: true,
                    title:
                        Text(Translations.of(context)!.text('changes_summary')),
                    children: _generateVersionListTiles(),
                  )
                : Container(),
          ],
        ),
      ),
    );
  }
}
