import 'dart:async';
import 'dart:io';

import 'package:dcoupon_sdk_flutter_package/src/presentation/widgets/platform_progress_indicator.dart';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

class WebviewDialogWidget extends StatefulWidget {
  final String? url;

  WebviewDialogWidget({
    Key? key,
    required this.url,
  }) : super(key: key);

  @override
  State<WebviewDialogWidget> createState() => _WebviewDialogWidgetState();
}

class _WebviewDialogWidgetState extends State<WebviewDialogWidget> {
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();

  bool _isLoadingPage = true;

  @override
  void initState() {
    if (Platform.isAndroid) WebView.platform = SurfaceAndroidWebView();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.only(
        top: 48.0,
        left: 8.0,
        bottom: 48.0,
      ),
      child: widget.url == null
          ? Container()
          : NotificationListener<OverscrollIndicatorNotification>(
              onNotification: (OverscrollIndicatorNotification overscroll) {
                overscroll.disallowIndicator();
                return false;
              },
              child: Container(
                padding: EdgeInsets.only(
                  top: 18.0,
                  bottom: 18.0,
                ),
                decoration: BoxDecoration(
                  color: Theme.of(context).scaffoldBackgroundColor,
                  borderRadius: BorderRadius.circular(10.0),
                ),
                child: Stack(
                  children: [
                    WebView(
                      onWebViewCreated: (WebViewController webViewController) {
                        _controller.complete(webViewController);
                      },
                      initialUrl: widget.url,
                      javascriptMode: JavascriptMode.unrestricted,
                      onPageFinished: (url) {
                        setState(() {
                          _isLoadingPage = false;
                        });
                      },
                    ),
                    _isLoadingPage
                        ? Container(
                            color: Theme.of(context).scaffoldBackgroundColor,
                            child: Center(
                              child: PlatformProgressIndicator(),
                            ),
                          )
                        : Container(),
                  ],
                ),
              ),
            ),
    );
  }
}
